yakumo.base.GlanceV2Resource

Package yakumo :: Module base :: Class GlanceV2Resource |
[hide private]
[frames] | no frames]

# Class GlanceV2Resource

source code

    object --+
             |
      Resource --+
                 |
                GlanceV2Resource

Known Subclasses:
  - glance.v2.image_member.Resource
  - , glance.v2.image.Resource

Base class for resource managers which don't use _json_resource_key.

Instance Methods | [hide private]
None |
update(self, **kwargs) Update a resource and reload it. | source code
Inherited from `Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, **kwargs) | source code
Update a resource and reload it. kwargs: attributes and their values to update Returns: None Overrides: Resource.update